@@ -5,7 +5,8 @@ if (Sys.getenv("Run_RPushbullet_Tests")=="yes") {
     ## one should store in a code repository.
     ##
     ## I put a request in to the authors of Pushbullet to provide a "test id" key, and they
-    ## are sympathetetic but to not have one yet.
+    ## are sympathetetic but do not have one implemented yet, and only suggested a woraround
+    # of a 'throwaway' GMail id which I find unappealing.
     stopifnot(file.exists("~/.rpushbullet.json"))
 
     library(RPushbullet)
@@ -28,5 +29,16 @@ if (Sys.getenv("Run_RPushbullet_Tests")=="yes") {
     str(fromJSON(pbGetDevices()))
 
     ## Post a note item
-    str(fromJSON(pbPost("note", "simple Test", "We think this should work.\nWe really do.")))
+    str(fromJSON(pbPost("note", "A Simple Test", "We think this should work.\nWe really do.")))
+
+    ## Post an address -- should open browser in Google Maps
+    str(fromJSON(pbPost(type="address", title="An Address", body="South Pole, Antarctica")))
+
+    ## Post a URL -- should open browser
+    str(fromJSON(pbPost(type="link", title="Some title", body="Some URL", 
+                        url="http://cran.r-project.org/package=RPushbullet")))
+    
+    ## Post a file
+    str(fromJSON(pbPost(type="file", url=system.file("DESCRIPTION", package="RPushbullet"))))
+
 }
